@@ -224,6 +224,14 @@ class Burner(object):
         for i in range(0, 3):
             SDCard.writefile(f"{card.root_volume}/etc/locale.gen", locale_gen)
 
+    def set_cmdline(self, cmdline):
+        card = SDCard()
+        filename = f'{card.boot_volume}/cmdline.txt'
+        content = Sudo.readfile(filename=filename, split=False, decode=True)
+        content = content.rstrip() + " " + cmdline
+        SDCard.writefile(filename=f'{card.boot_volume}/cmdline.txt',
+                         content=content)
+
     @windows_not_supported
     def set_hostname(self, hostname):
         """
@@ -916,7 +924,8 @@ class Burner(object):
 
             Console.info(f"Completed workers: {workers}")
             Console.info("Cluster burn is complete.")
-            Burner.remove_public_key()
+            # Burner.remove_public_key()
+            # TODO remove public key on GUI close or single cluster cmd complete
 
         banner("Benchmark", figlet=True)
 
